# WorkItemExtractionModel

Rules for different level entities inclusion/exclusion

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**include_work_items** | **[str]** | Identifiers of work items to be included | [optional] 
**include_sections** | **[str]** | Identifiers of sections to be included | [optional] 
**include_projects** | **[str]** | Identifiers of projects to be included | [optional] 
**exclude_work_items** | **[str]** | Identifiers of work items to be excluded | [optional] 
**exclude_sections** | **[str]** | Identifiers of sections to be excluded | [optional] 
**exclude_projects** | **[str]** | Identifiers of projects to be excluded | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


